aboutsummaryrefslogtreecommitdiff
path: root/LAPACKE/src/lapacke_cheevd_2stage_work.c
diff options
context:
space:
mode:
Diffstat (limited to 'LAPACKE/src/lapacke_cheevd_2stage_work.c')
-rw-r--r--LAPACKE/src/lapacke_cheevd_2stage_work.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/LAPACKE/src/lapacke_cheevd_2stage_work.c b/LAPACKE/src/lapacke_cheevd_2stage_work.c
index 81869c56..22334c9d 100644
--- a/LAPACKE/src/lapacke_cheevd_2stage_work.c
+++ b/LAPACKE/src/lapacke_cheevd_2stage_work.c
@@ -26,14 +26,14 @@
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
THE POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************
* Contents: Native middle-level C interface to LAPACK function cheevd
* Author: Intel Corporation
* Generated November 2015
*****************************************************************************/
#include "lapacke_utils.h"
-lapack_int LAPACKE_cheevd_work( int matrix_layout, char jobz, char uplo,
+lapack_int LAPACKE_cheevd_2stage_work( int matrix_layout, char jobz, char uplo,
lapack_int n, lapack_complex_float* a,
lapack_int lda, float* w,
lapack_complex_float* work, lapack_int lwork,
@@ -43,7 +43,7 @@ lapack_int LAPACKE_cheevd_work( int matrix_layout, char jobz, char uplo,
lapack_int info = 0;
if( matrix_layout == LAPACK_COL_MAJOR ) {
/* Call LAPACK function and adjust info */
- LAPACK_cheevd( &jobz, &uplo, &n, a, &lda, w, work, &lwork, rwork,
+ LAPACK_cheevd_2stage( &jobz, &uplo, &n, a, &lda, w, work, &lwork, rwork,
&lrwork, iwork, &liwork, &info );
if( info < 0 ) {
info = info - 1;
@@ -54,12 +54,12 @@ lapack_int LAPACKE_cheevd_work( int matrix_layout, char jobz, char uplo,
/* Check leading dimension(s) */
if( lda < n ) {
info = -6;
- LAPACKE_xerbla( "LAPACKE_cheevd_work", info );
+ LAPACKE_xerbla( "LAPACKE_cheevd_2stage_work", info );
return info;
}
/* Query optimal working array(s) size if requested */
if( liwork == -1 || lrwork == -1 || lwork == -1 ) {
- LAPACK_cheevd( &jobz, &uplo, &n, a, &lda_t, w, work, &lwork, rwork,
+ LAPACK_cheevd_2stage( &jobz, &uplo, &n, a, &lda_t, w, work, &lwork, rwork,
&lrwork, iwork, &liwork, &info );
return (info < 0) ? (info - 1) : info;
}
@@ -73,7 +73,7 @@ lapack_int LAPACKE_cheevd_work( int matrix_layout, char jobz, char uplo,
/* Transpose input matrices */
LAPACKE_cge_trans( matrix_layout, n, n, a, lda, a_t, lda_t );
/* Call LAPACK function and adjust info */
- LAPACK_cheevd( &jobz, &uplo, &n, a_t, &lda_t, w, work, &lwork, rwork,
+ LAPACK_cheevd_2stage( &jobz, &uplo, &n, a_t, &lda_t, w, work, &lwork, rwork,
&lrwork, iwork, &liwork, &info );
if( info < 0 ) {
info = info - 1;
@@ -84,11 +84,11 @@ lapack_int LAPACKE_cheevd_work( int matrix_layout, char jobz, char uplo,
LAPACKE_free( a_t );
exit_level_0:
if( info == LAPACK_TRANSPOSE_MEMORY_ERROR ) {
- LAPACKE_xerbla( "LAPACKE_cheevd_work", info );
+ LAPACKE_xerbla( "LAPACKE_cheevd_2stage_work", info );
}
} else {
info = -1;
- LAPACKE_xerbla( "LAPACKE_cheevd_work", info );
+ LAPACKE_xerbla( "LAPACKE_cheevd_2stage_work", info );
}
return info;
}
@@ -26,14 +26,14 @@
THE POSSIBILITY OF SUCH DAMAGE.
*****************************************************************************
-* Contents: Native middle-level C interface to LAPACK function cheevd
+* Contents: Native middle-level C interface to LAPACK function cheevd_2stage
* Author: Intel Corporation
* Generated November 2015